#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_SINCOSPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_SINCOSPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/fast_sincospi.hpp>

#endif
